@@ -127,7 +127,7 @@ arg_parser.add_argument(
     default=None,
 )
 arg_parser.add_argument(
-    '--use_non_positive_negative_number_constrained_types',
+    '--use-non-positive-negative-number-constrained-types',
     help='Use the Non{Positive,Negative}{FloatInt} types instead of the corresponding con* constrained types.',
     action='store_true',
     default=None,
@@ -144,6 +144,12 @@ arg_parser.add_argument(
     action='store_true',
     default=None,
 )
+arg_parser.add_argument(
+    '--field-extra-keys-without-x-prefix',
+    help='Add extra keys with `x-` prefix to field parameters. The extra keys are stripped of the `x-` prefix.',
+    type=str,
+    nargs='+',
+)
 arg_parser.add_argument(
     '--snake-case-field',
     help='Change camel-case field name to snake-case',
@@ -224,6 +230,13 @@ arg_parser.add_argument(
     default=None,
 )
 
+arg_parser.add_argument(
+    '--enable-version-header',
+    help='Enable package version on file headers',
+    action='store_true',
+    default=None,
+)
+
 arg_parser.add_argument(
     '--use-standard-collections',
     help='Use standard collections for type hinting (list, dict)',
@@ -272,6 +285,12 @@ arg_parser.add_argument(
     default=None,
 )
 
+arg_parser.add_argument(
+    '--keep-model-order',
+    help='Keep generated models\' order',
+    action='store_true',
+    default=None,
+)
 
 arg_parser.add_argument(
     "--collapse-root-models",
@@ -506,6 +525,7 @@ class Config(BaseModel):
     strip_default_none: bool = False
     aliases: Optional[TextIOBase]
     disable_timestamp: bool = False
+    enable_version_header: bool = False
     allow_population_by_field_name: bool = False
     allow_extra_fields: bool = False
     use_default: bool = False
@@ -530,6 +550,7 @@ class Config(BaseModel):
     empty_enum_field_name: Optional[str] = None
     field_extra_keys: Optional[Set[str]] = None
     field_include_all_keys: bool = False
+    field_extra_keys_without_x_prefix: Optional[Set[str]] = None
     openapi_scopes: Optional[List[OpenAPIScope]] = [OpenAPIScope.Schemas]
     wrap_string_literal: Optional[bool] = None
     use_title_as_name: bool = False
@@ -543,6 +564,7 @@ class Config(BaseModel):
     special_field_name_prefix: Optional[str] = None
     remove_special_field_name_prefix: bool = False
     capitalise_enum_members: bool = False
+    keep_model_order: bool = False
 
     def merge_args(self, args: Namespace) -> None:
         set_args = {
@@ -660,6 +682,7 @@ def main(args: Optional[Sequence[str]] = None) -> Exit:
             extra_template_data=extra_template_data,
             aliases=aliases,
             disable_timestamp=config.disable_timestamp,
+            enable_version_header=config.enable_version_header,
             allow_population_by_field_name=config.allow_population_by_field_name,
             allow_extra_fields=config.allow_extra_fields,
             apply_default_values_for_required_fields=config.use_default,
@@ -682,6 +705,7 @@ def main(args: Optional[Sequence[str]] = None) -> Exit:
             empty_enum_field_name=config.empty_enum_field_name,
             field_extra_keys=config.field_extra_keys,
             field_include_all_keys=config.field_include_all_keys,
+            field_extra_keys_without_x_prefix=config.field_extra_keys_without_x_prefix,
             openapi_scopes=config.openapi_scopes,
             wrap_string_literal=config.wrap_string_literal,
             use_title_as_name=config.use_title_as_name,
@@ -696,6 +720,7 @@ def main(args: Optional[Sequence[str]] = None) -> Exit:
             special_field_name_prefix=config.special_field_name_prefix,
             remove_special_field_name_prefix=config.remove_special_field_name_prefix,
             capitalise_enum_members=config.capitalise_enum_members,
+            keep_model_order=config.keep_model_order,
         )
         return Exit.OK
     except InvalidClassNameError as e:
