@@ -35,7 +35,6 @@ class DataModelField(DataModelFieldBase):
     _EXCLUDE_FIELD_KEYS: ClassVar[Set[str]] = {
         'alias',
         'default',
-        'default_factory',
         'const',
         'gt',
         'ge',
@@ -96,6 +95,27 @@ class DataModelField(DataModelFieldBase):
                 break
         return value
 
+    def _get_default_as_pydantic_model(self) -> Optional[str]:
+        for data_type in self.data_type.data_types or (self.data_type,):
+            # TODO: Check nested data_types
+            if data_type.is_dict or self.data_type.is_union:
+                # TODO: Parse Union and dict model for default
+                continue
+            elif data_type.is_list and len(data_type.data_types) == 1:
+                data_type = data_type.data_types[0]
+                data_type.alias
+                if (
+                    data_type.reference
+                    and isinstance(data_type.reference.source, BaseModel)
+                    and isinstance(self.default, list)
+                ):  # pragma: no cover
+                    return f'lambda :[{data_type.alias or data_type.reference.source.class_name}.parse_obj(v) for v in {repr(self.default)}]'
+            elif data_type.reference and isinstance(
+                data_type.reference.source, BaseModel
+            ):  # pragma: no cover
+                return f'lambda :{data_type.alias or data_type.reference.source.class_name}.parse_obj({repr(self.default)})'
+        return None
+
     def __str__(self) -> str:
         data: Dict[str, Any] = {
             k: v for k, v in self.extras.items() if k not in self._EXCLUDE_FIELD_KEYS
@@ -121,20 +141,39 @@ class DataModelField(DataModelFieldBase):
         if self.const:
             data['const'] = True
 
+        discriminator = data.pop('discriminator', None)
+        if discriminator:
+            if isinstance(discriminator, str):
+                data['discriminator'] = discriminator
+            elif isinstance(discriminator, dict):  # pragma: no cover
+                data['discriminator'] = discriminator['propertyName']
+
+        if self.required:
+            default_factory = None
+        elif self.default and 'default_factory' not in data:
+            default_factory = self._get_default_as_pydantic_model()
+        else:
+            default_factory = data.pop('default_factory', None)
+
         field_arguments = sorted(
             f"{k}={repr(v)}" for k, v in data.items() if v is not None
         )
-        if not field_arguments:
+
+        if not field_arguments and not default_factory:
             if self.nullable and self.required:
                 return 'Field(...)'  # Field() is for mypy
             return ""
 
-        kwargs = ",".join(field_arguments)
         if self.use_annotated:
-            return f'Field({kwargs})'
-        value_arg = "..." if self.required else repr(self.default)
+            pass
+        elif self.required:
+            field_arguments = ['...', *field_arguments]
+        elif default_factory:
+            field_arguments = [f'default_factory={default_factory}', *field_arguments]
+        else:
+            field_arguments = [f'{repr(self.default)}', *field_arguments]
 
-        return f'Field({value_arg}, {kwargs})'
+        return f'Field({", ".join(field_arguments)})'
 
     @property
     def annotated(self) -> Optional[str]:
