@@ -37,15 +37,10 @@ from datamodel_code_generator.model.base import (
     DataModel,
     DataModelFieldBase,
 )
-from datamodel_code_generator.model.enum import Enum
+from datamodel_code_generator.model.enum import Enum, Member
 from datamodel_code_generator.parser import DefaultPutDict, LiteralType
 from datamodel_code_generator.reference import ModelResolver, Reference
-from datamodel_code_generator.types import (
-    DataType,
-    DataTypeManager,
-    Modular,
-    StrictTypes,
-)
+from datamodel_code_generator.types import DataType, DataTypeManager, StrictTypes
 
 escape_characters = str.maketrans(
     {
@@ -348,6 +343,7 @@ class Parser(ABC):
         ] = title_to_class_name,
         field_extra_keys: Optional[Set[str]] = None,
         field_include_all_keys: bool = False,
+        field_extra_keys_without_x_prefix: Optional[Set[str]] = None,
         wrap_string_literal: Optional[bool] = None,
         use_title_as_name: bool = False,
         http_headers: Optional[Sequence[Tuple[str, str]]] = None,
@@ -362,6 +358,7 @@ class Parser(ABC):
         special_field_name_prefix: Optional[str] = None,
         remove_special_field_name_prefix: bool = False,
         capitalise_enum_members: bool = False,
+        keep_model_order: bool = False,
     ):
         self.data_type_manager: DataTypeManager = data_type_manager_type(
             python_version=target_python_version,
@@ -406,6 +403,9 @@ class Parser(ABC):
             Callable[[str], str]
         ] = custom_class_name_generator
         self.field_extra_keys: Set[str] = field_extra_keys or set()
+        self.field_extra_keys_without_x_prefix: Set[str] = (
+            field_extra_keys_without_x_prefix or set()
+        )
         self.field_include_all_keys: bool = field_include_all_keys
 
         self.remote_text_cache: DefaultPutDict[str, str] = (
@@ -467,6 +467,7 @@ class Parser(ABC):
         self.allow_responses_without_content = allow_responses_without_content
         self.collapse_root_models = collapse_root_models
         self.capitalise_enum_members = capitalise_enum_members
+        self.keep_model_order = keep_model_order
 
     @property
     def iter_source(self) -> Iterator[Source]:
@@ -474,7 +475,12 @@ class Parser(ABC):
             yield Source(path=Path(), text=self.source)
         elif isinstance(self.source, Path):  # pragma: no cover
             if self.source.is_dir():
-                for path in self.source.rglob('*'):
+                paths = (
+                    sorted(self.source.rglob('*'))
+                    if self.keep_model_order
+                    else self.source.rglob('*')
+                )
+                for path in paths:
                     if path.is_file():
                         yield Source.from_path(path, self.base_path, self.encoding)
             else:
@@ -516,6 +522,10 @@ class Parser(ABC):
         raise NotImplementedError
 
     def __delete_duplicate_models(self, models: List[DataModel]) -> None:
+        model_class_names: Dict[str, DataModel] = {}
+        model_to_duplicate_models: DefaultDict[
+            DataModel, List[DataModel]
+        ] = defaultdict(list)
         for model in models[:]:
             if isinstance(model, self.data_model_root_type):
                 root_data_type = model.fields[0].data_type
@@ -548,9 +558,44 @@ class Parser(ABC):
                         for base_class in child.base_classes[:]:
                             if base_class.reference == model.reference:
                                 child.base_classes.remove(base_class)
-                        if not child.base_classes:
+                        if not child.base_classes:  # pragma: no cover
                             child.set_base_class()
 
+            class_name = model.duplicate_class_name or model.class_name
+            if class_name in model_class_names:
+                model_key = tuple(
+                    to_hashable(v)
+                    for v in (
+                        model.base_classes,
+                        model.extra_template_data,
+                        model.fields,
+                        model.description,
+                        model.default,
+                        model.decorators,
+                    )
+                )
+                original_model = model_class_names[class_name]
+                original_model_key = tuple(
+                    to_hashable(v)
+                    for v in (
+                        original_model.base_classes,
+                        original_model.extra_template_data,
+                        original_model.fields,
+                        original_model.description,
+                        original_model.default,
+                        original_model.decorators,
+                    )
+                )
+                if model_key == original_model_key:
+                    model_to_duplicate_models[original_model].append(model)
+                    continue
+            model_class_names[class_name] = model
+        for model, duplicate_models in model_to_duplicate_models.items():
+            for duplicate_model in duplicate_models:
+                for child in duplicate_model.reference.children[:]:
+                    child.replace_reference(model.reference)
+                models.remove(duplicate_model)
+
     @classmethod
     def __replace_duplicate_name_in_module(cls, models: List[DataModel]) -> None:
         scoped_model_resolver = ModelResolver(
@@ -566,13 +611,15 @@ class Parser(ABC):
             ).name
             if class_name != generated_name:
                 model.class_name = generated_name
-            model_names[model.name] = model
+            model_names[model.class_name] = model
 
         for model in models:
             duplicate_name = model.duplicate_class_name
             # check only first desired name
             if duplicate_name and duplicate_name not in model_names:
+                del model_names[model.class_name]
                 model.class_name = duplicate_name
+                model_names[duplicate_name] = model
 
     @classmethod
     def __change_from_import(
@@ -582,6 +629,8 @@ class Parser(ABC):
         scoped_model_resolver: ModelResolver,
         init: bool,
     ) -> None:
+        for model in models:
+            scoped_model_resolver.add(model.path, model.class_name)
         for model in models:
             imports.append(model.imports)
             for data_type in model.all_data_types:
@@ -605,7 +654,11 @@ class Parser(ABC):
 
                 name = data_type.reference.short_name
                 if from_ and import_ and alias != name:
-                    data_type.alias = f'{alias}.{name}'
+                    data_type.alias = (
+                        alias
+                        if from_ == '.' and data_type.full_name == import_
+                        else f'{alias}.{name}'
+                    )
 
                 if init:
                     from_ = "." + from_
@@ -778,9 +831,6 @@ class Parser(ABC):
     def __set_default_enum_member(
         self,
         models: List[DataModel],
-        imports: Imports,
-        scoped_model_resolver: ModelResolver,
-        init: bool,
     ) -> None:
         if not self.set_default_enum_member:
             return None
@@ -792,34 +842,28 @@ class Parser(ABC):
                     if data_type.reference and isinstance(
                         data_type.reference.source, Enum
                     ):  # pragma: no cover
-                        enum_member = data_type.reference.source.find_member(
-                            model_field.default
-                        )
-                        if enum_member:
-                            model_field.default = enum_member
-                            enum_member_enum = enum_member.enum
-                            if enum_member_enum in models:
-                                continue
-                            scoped_model_resolver.get(enum_member_enum.path)
-                            if isinstance(enum_member_enum, Modular):
-                                enum_member_enum_name = f'{enum_member_enum.module_name}.{enum_member.enum.name}'
+                        if isinstance(model_field.default, list):
+                            enum_member: Union[List[Member], Optional[Member]] = [
+                                e
+                                for e in (
+                                    data_type.reference.source.find_member(d)
+                                    for d in model_field.default
+                                )
+                                if e
+                            ]
+                        else:
+                            enum_member = data_type.reference.source.find_member(
+                                model_field.default
+                            )
+                        if not enum_member:
+                            continue
+                        model_field.default = enum_member
+                        if data_type.alias:
+                            if isinstance(enum_member, list):
+                                for enum_member_ in enum_member:
+                                    enum_member_.alias = data_type.alias
                             else:
-                                enum_member_enum_name = enum_member.enum.name
-                            from_, import_ = full_path = relative(
-                                model.module_name, enum_member_enum_name
-                            )
-
-                            alias = scoped_model_resolver.add(full_path, import_).name
-
-                            name = data_type.reference.short_name
-                            if from_ and import_ and alias != name:
-                                enum_member.alias = f'{alias}.{name}'
-
-                            if init:
-                                from_ += "."
-                            imports.append(
-                                Import(from_=from_, import_=import_, alias=alias)
-                            )
+                                enum_member.alias = data_type.alias
 
     def __override_required_field(
         self,
@@ -867,6 +911,37 @@ class Parser(ABC):
                 model.fields.insert(index, copied_original_field)
                 model.fields.remove(model_field)
 
+    def __sort_models(
+        self,
+        models: List[DataModel],
+        imports: Imports,
+    ) -> None:
+        if not self.keep_model_order:
+            return
+
+        models.sort(key=lambda x: x.class_name)
+
+        imported = set(i for v in imports.values() for i in v)
+        model_class_name_baseclasses: Dict[DataModel, Tuple[str, Set[str]]] = {}
+        for model in models:
+            class_name = model.class_name
+            model_class_name_baseclasses[model] = class_name, {
+                b.type_hint for b in model.base_classes if b.reference
+            } - {class_name}
+
+        changed: bool = True
+        while changed:
+            changed = False
+            resolved = imported.copy()
+            for i in range(len(models) - 1):
+                model = models[i]
+                class_name, baseclasses = model_class_name_baseclasses[model]
+                if not baseclasses - resolved:
+                    resolved.add(class_name)
+                    continue
+                models[i], models[i + 1] = models[i + 1], model
+                changed = True
+
     def parse(
         self,
         with_import: Optional[bool] = True,
@@ -895,7 +970,9 @@ class Parser(ABC):
         )
 
         results: Dict[Tuple[str, ...], Result] = {}
-        module_key = lambda x: x.module_path
+
+        def module_key(data_model: DataModel) -> Tuple[str, ...]:
+            return tuple(data_model.module_path)
 
         # process in reverse order to correctly establish module levels
         grouped_models = groupby(
@@ -944,13 +1021,15 @@ class Parser(ABC):
 
             imports = Imports()
             scoped_model_resolver = ModelResolver()
+
             self.__change_from_import(models, imports, scoped_model_resolver, init)
             self.__extract_inherited_enum(models)
             self.__set_reference_default_value_to_field(models)
             self.__reuse_model(models, require_update_action_models)
             self.__collapse_root_models(models, unused_models)
-            self.__set_default_enum_member(models, imports, scoped_model_resolver, init)
+            self.__set_default_enum_member(models)
             self.__override_required_field(models)
+            self.__sort_models(models, imports)
 
             processed_models.append(Processed(module, models, init, imports))
 
