@@ -21,6 +21,8 @@ from typing import (
     Union,
 )
 
+import pydantic
+from packaging import version
 from pydantic import StrictBool, StrictInt, StrictStr, create_model
 
 from datamodel_code_generator import Protocol, runtime_checkable
@@ -62,10 +64,21 @@ class Modular(Protocol):
         raise NotImplementedError
 
 
+@runtime_checkable
+class Nullable(Protocol):
+    @property
+    def nullable(self) -> bool:
+        raise NotImplementedError
+
+
 class DataType(_BaseModel):
     class Config:
-        extra = "forbid"
-        copy_on_model_validation = False
+        extra = 'forbid'
+        copy_on_model_validation = (
+            False
+            if version.parse(pydantic.VERSION) < version.parse('1.9.2')
+            else 'none'
+        )
 
     type: Optional[str]
     reference: Optional[Reference]
@@ -127,16 +140,22 @@ class DataType(_BaseModel):
             | ({self.reference.path} if self.reference else set())
         )
 
-    def replace_reference(self, reference: Reference) -> None:
+    def replace_reference(self, reference: Optional[Reference]) -> None:
         if not self.reference:  # pragma: no cover
             raise Exception(
                 f'`{self.__class__.__name__}.replace_reference()` can\'t be called'
                 f' when `reference` field is empty.'
             )
-
-        self.reference.children.remove(self)
+        self_id = id(self)
+        self.reference.children = [
+            c for c in self.reference.children if id(c) != self_id
+        ]
         self.reference = reference
-        reference.children.append(self)
+        if reference:
+            reference.children.append(self)
+
+    def remove_reference(self) -> None:
+        self.replace_reference(None)
 
     @property
     def module_name(self) -> Optional[str]:
@@ -256,6 +275,10 @@ class DataType(_BaseModel):
                     # TODO support strict Any
                     # type_ = 'Any'
                     type_ = ''
+        if self.reference:
+            source = self.reference.source
+            if isinstance(source, Nullable) and source.nullable:
+                self.is_optional = True
         if self.reference and self.python_version == PythonVersion.PY_36:
             type_ = f"'{type_}'"
         if self.is_list:
@@ -279,7 +302,7 @@ class DataType(_BaseModel):
             else:  # pragma: no cover
                 type_ = dict_
         if self.is_optional and type_ != 'Any':
-            if self.use_union_operator:
+            if self.use_union_operator:  # pragma: no cover
                 type_ = f'{type_} | None'
             else:
                 type_ = f'Optional[{type_}]'
@@ -391,3 +414,21 @@ class DataTypeManager(ABC):
         return self.data_type.from_import(
             Import.from_full_path(full_path), is_custom_type=is_custom_type
         )
+
+    def get_data_type_from_value(self, value: Any) -> DataType:
+        type_: Optional[Types] = None
+        if isinstance(value, str):
+            type_ = Types.string
+        elif isinstance(value, bool):
+            type_ = Types.boolean
+        elif isinstance(value, int):
+            type_ = Types.integer
+        elif isinstance(value, float):
+            type_ = Types.float
+        elif isinstance(value, dict):
+            return self.data_type.from_import(IMPORT_DICT)
+        elif isinstance(value, list):
+            return self.data_type.from_import(IMPORT_LIST)
+        else:
+            type_ = Types.any
+        return self.get_data_type(type_)
